Attribute

Enum Attribute 

#[repr(u16)]
pub enum Attribute {
Show 61 variants BatadvAttrUnspec = 0, BatadvAttrVersion = 1, BatadvAttrAlgoName = 2, BatadvAttrMeshIfindex = 3, BatadvAttrMeshIfname = 4, BatadvAttrMeshAddress = 5, BatadvAttrHardIfindex = 6, BatadvAttrHardIfname = 7, BatadvAttrHardAddress = 8, BatadvAttrOrigAddress = 9, BatadvAttrTpMeterResult = 10, BatadvAttrTpMeterTestTime = 11, BatadvAttrTpMeterBytes = 12, BatadvAttrTpMeterCookie = 13, BatadvAttrPad = 14, BatadvAttrActive = 15, BatadvAttrTtAddress = 16, BatadvAttrTtTtvn = 17, BatadvAttrTtLastTtvn = 18, BatadvAttrTtCrc32 = 19, BatadvAttrTtVid = 20, BatadvAttrTtFlags = 21, BatadvAttrFlagBest = 22, BatadvAttrLastSeenMsecs = 23, BatadvAttrNeighAddress = 24, BatadvAttrTq = 25, BatadvAttrThroughput = 26, BatadvAttrBandwidthUp = 27, BatadvAttrBandwidthDown = 28, BatadvAttrRouter = 29, BatadvAttrBlaOwn = 30, BatadvAttrBlaAddress = 31, BatadvAttrBlaVid = 32, BatadvAttrBlaBackbone = 33, BatadvAttrBlaCrc = 34, BatadvAttrDatCacheIp4Address = 35, BatadvAttrDatCacheHwAddress = 36, BatadvAttrDatCacheVid = 37, BatadvAttrMcastFlags = 38, BatadvAttrMcastFlagsPriv = 39, BatadvAttrVlanId = 40, BatadvAttrAggregatedOgmsEnabled = 41, BatadvAttrApIsolationEnabled = 42, BatadvAttrIsolationMark = 43, BatadvAttrIsolationMask = 44, BatadvAttrBondingEnabled = 45, BatadvAttrBridgeLoopAvoidanceEnabled = 46, BatadvAttrDistributedArpTableEnabled = 47, BatadvAttrFragmentationEnabled = 48, BatadvAttrGwBandwidthDown = 49, BatadvAttrGwBandwidthUp = 50, BatadvAttrGwMode = 51, BatadvAttrGwSelClass = 52, BatadvAttrHopPenalty = 53, BatadvAttrLogLevel = 54, BatadvAttrMulticastForceFloodEnabled = 55, BatadvAttrNetworkCodingEnabled = 56, BatadvAttrOrigInterval = 57, BatadvAttrElpInterval = 58, BatadvAttrThroughputOverride = 59, BatadvAttrMulticastFanout = 60,
}
BATMAN-adv Netlink attributes (from linux/uapi/batman_adv.h).

These attributes are used when communicating with the kernel via the BATMAN-adv generic netlink interface. They represent various settings, metrics, and state information for mesh interfaces, translation tables, neighbors, gateways, and protocol features.

Variants



BatadvAttrUnspec = 0

Unspecified / placeholder attribute.



BatadvAttrVersion = 1

BATMAN-adv protocol version.



BatadvAttrAlgoName = 2

Name of the routing algorithm in use.



BatadvAttrMeshIfindex = 3

Mesh interface index.



BatadvAttrMeshIfname = 4

Mesh interface name.



BatadvAttrMeshAddress = 5

MAC address of the mesh interface.



BatadvAttrHardIfindex = 6

Hard interface index.



BatadvAttrHardIfname = 7

Hard interface name.



BatadvAttrHardAddress = 8

MAC address of the hard interface.



BatadvAttrOrigAddress = 9

Originator (source) MAC address.



BatadvAttrTpMeterResult = 10

Throughput meter result.



BatadvAttrTpMeterTestTime = 11

Throughput test duration in seconds.



BatadvAttrTpMeterBytes = 12

Number of bytes transferred in throughput test.



BatadvAttrTpMeterCookie = 13

Throughput meter cookie.



BatadvAttrPad = 14

Padding attribute (unused).



BatadvAttrActive = 15

Interface active state.



BatadvAttrTtAddress = 16

Translation table client MAC address.



BatadvAttrTtTtvn = 17

Translation table TTVN.



BatadvAttrTtLastTtvn = 18

Last TTVN in translation table.



BatadvAttrTtCrc32 = 19

CRC32 for translation table entry.



BatadvAttrTtVid = 20

VLAN ID for translation table entry.



BatadvAttrTtFlags = 21

Flags for translation table entry (see ClientFlags).



BatadvAttrFlagBest = 22

Marks the “best” client in the translation table.



BatadvAttrLastSeenMsecs = 23

Last seen timestamp in milliseconds.



BatadvAttrNeighAddress = 24

Neighbor MAC address.



BatadvAttrTq = 25

Transmission quality (TQ) metric.



BatadvAttrThroughput = 26

Throughput in bytes per second (optional, BATMAN_V).



BatadvAttrBandwidthUp = 27

Gateway bandwidth upstream (kbit/s).



BatadvAttrBandwidthDown = 28

Gateway bandwidth downstream (kbit/s).



BatadvAttrRouter = 29

Gateway MAC address for router.



BatadvAttrBlaOwn = 30

Backbone link advertisement (BLA) own attribute.



BatadvAttrBlaAddress = 31

BLA MAC address.



BatadvAttrBlaVid = 32

BLA VLAN ID.



BatadvAttrBlaBackbone = 33

BLA backbone flag.



BatadvAttrBlaCrc = 34

BLA CRC.



BatadvAttrDatCacheIp4Address = 35

DAT IPv4 address.



BatadvAttrDatCacheHwAddress = 36

DAT hardware (MAC) address.



BatadvAttrDatCacheVid = 37

DAT VLAN ID.



BatadvAttrMcastFlags = 38

Multicast flags.



BatadvAttrMcastFlagsPriv = 39

Private multicast flags.



BatadvAttrVlanId = 40

VLAN ID.



BatadvAttrAggregatedOgmsEnabled = 41

OGMs aggregation enabled.



BatadvAttrApIsolationEnabled = 42

AP isolation enabled.



BatadvAttrIsolationMark = 43

Isolation mark.



BatadvAttrIsolationMask = 44

Isolation mask.



BatadvAttrBondingEnabled = 45

Bonding enabled flag.



BatadvAttrBridgeLoopAvoidanceEnabled = 46

Bridge loop avoidance enabled flag.



BatadvAttrDistributedArpTableEnabled = 47

Distributed ARP table enabled flag.



BatadvAttrFragmentationEnabled = 48

Fragmentation enabled flag.



BatadvAttrGwBandwidthDown = 49

Gateway bandwidth downstream.



BatadvAttrGwBandwidthUp = 50

Gateway bandwidth upstream.



BatadvAttrGwMode = 51

Gateway mode (off/client/server).



BatadvAttrGwSelClass = 52

Gateway selection class.



BatadvAttrHopPenalty = 53

Hop penalty.



BatadvAttrLogLevel = 54

Log level.



BatadvAttrMulticastForceFloodEnabled = 55

Force multicast flooding enabled.



BatadvAttrNetworkCodingEnabled = 56

Network coding enabled.



BatadvAttrOrigInterval = 57

Originator interval.



BatadvAttrElpInterval = 58

ELP interval.



BatadvAttrThroughputOverride = 59

Throughput override.



BatadvAttrMulticastFanout = 60

Multicast fanout.