#[repr(u8)]pub enum GatewayEventAction {
Add = 1,
Change = 2,
Delete = 3,
}Expand description
Gateway event action types
These correspond to batman-adv’s BATACTION uevent field.
Variants
Add = 1
First gateway was selected (ADD)
This event is sent when a batman-adv node transitions to having a selected gateway. Applications should typically start a DHCP client on this event.
Change = 2
A better gateway was found (CHANGE)
This event is sent when a batman-adv node switches to a different gateway due to improved link quality or other selection criteria. Applications should typically renew their DHCP lease on this event.
Delete = 3
The selected gateway is no longer available (DEL)
This event is sent when the currently selected gateway disappears
and no alternative gateway is available. The gateway_mac field
will be None for this action.