pub fn cmd_bridge_loop_avoidance() -> CommandExpand description
Creates the CLI command for querying or modifying the bridge loop avoidance setting.
Returns
- A
clap::Commandconfigured with:- Name:
"bridge_loop_avoidance" - Alias:
"bl" - Short and long description:
"Display or modify bridge_loop_avoidance setting." - Usage override:
robctl [options] bridge_loop_avoidance|bl [options] [0|1] - Optional argument
value:- Type:
u8 - Allowed values:
0(disable) or1(enable) - Help:
"0 = disable bridge_loop_avoidance, 1 = enable bridge_loop_avoidance"
- Type:
- Name:
Notes
- If no
valueis provided, the command can be used to display the current bridge loop avoidance state. - Version flag is disabled for this command.