pub struct GatewayEvent {
pub timestamp: SystemTime,
pub meshif: u32,
pub meshif_name: String,
pub action: GatewayEventAction,
pub gateway_mac: Option<MacAddr>,
}Expand description
Gateway change event emitted by batman-adv kernel module.
When a batman-adv node is in gateway client mode, it emits uevents when the selected gateway changes. Applications can subscribe to these events to perform actions like starting/renewing DHCP leases.
Examples
ⓘ
let client = batman_robin::Client::new();
let mut events = client
.subscribe_gateway_events(batman_robin::MeshSelector::with_name("bat0"))
.await?;
while let Some(event) = events.next().await {
match event?.action {
GatewayEventAction::Add => println!("Gateway selected: {:?}", event?.gateway_mac),
GatewayEventAction::Change => println!("Better gateway found"),
GatewayEventAction::Delete => println!("Gateway lost"),
}
}Fields
timestamp: SystemTimeTimestamp when the event was received
meshif: u32Mesh interface index (e.g. from if_nametoindex("bat0"))
meshif_name: StringMesh interface name (e.g. “bat0”)
action: GatewayEventActionType of gateway change event
gateway_mac: Option<MacAddr>MAC address of the selected gateway (present for ADD/CHANGE, absent for DELETE)
Implementations
Sourceimpl GatewayEvent
impl GatewayEvent
Sourcepub fn new(
meshif: u32,
meshif_name: String,
action: GatewayEventAction,
gateway_mac: Option<MacAddr>,
) -> Self
pub fn new( meshif: u32, meshif_name: String, action: GatewayEventAction, gateway_mac: Option<MacAddr>, ) -> Self
Create a new gateway event
Sourcepub fn has_gateway(&self) -> bool
pub fn has_gateway(&self) -> bool
Check if this event has a valid associated gateway MAC